# New in 0.14.6 (2021-02-05)

Bug fixes, minor improvements of docs, code formatting.

## Changes

-   Update black formatting to stable release ([#1324])
-   Refresh readme, move tasks image to docs ([#1311]).
-   Add 0.14.5 release note to index ([#1296]).
-   Add test to ensure extra {class}`~scvi.model.SCANVI` training of a pre-trained {class}`~scvi.model.SCVI` model does not change original model weights ([#1284]).
-   Fix issue in {class}`~scvi.model.TOTALVI` protein background prior initialization to not include protein measurements that are known to be missing ([#1282]).
-   Upper bound setuptools due to PyTorch import bug ([#1309]).

## Contributors

-   [@adamgayoso]
-   [@watiss]
-   [@jjhong922]

[#1282]: https://github.com/YosefLab/scvi-tools/pull/1282
[#1284]: https://github.com/YosefLab/scvi-tools/pull/1284
[#1296]: https://github.com/YosefLab/scvi-tools/pull/1296
[#1309]: https://github.com/YosefLab/scvi-tools/pull/1309
[#1311]: https://github.com/YosefLab/scvi-tools/pull/1311
[#1324]: https://github.com/YosefLab/scvi-tools/pull/1324
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
[@watiss]: https://github.com/watiss
